@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
-# $Date: 2004/10/03 18:32:30 $
-# $Revision: 1.1.1.1.2.2 $
+# $Date: 2005/01/18 21:41:14 $
+# $Revision: 1.2.2.4 $
 
 use strict;
 use warnings;
@@ -10,8 +10,7 @@ use Getopt::Std;
 my %opts;
 getopts('d:f:v347khp', \%opts);
 
-die "Usage: sniffer.pl [ -f filter ] [ -d device ] [ -v ] [ -3 ] [ -4 ] ".
-    "[ -7 ] [ -p ]\n".
+die "Usage: sniffer.pl [-f filter] [-d device] [-v] [-3] [-4] [-7] [-p]\n".
     " -d:   device to sniff on\n".
     " -f:   filter to use\n".
     " -3:   print layer 3\n".
@@ -23,25 +22,28 @@ die "Usage: sniffer.pl [ -f filter ] [ -d device ] [ -v ] [ -3 ] [ -4 ] ".
     ""
    if $opts{h};
 
-use Net::Packet qw(:globals);
+use Net::Pkt;
 
-$Debug   = 3        if     $opts{v};
-$Dev     = $opts{d} if     $opts{d};
-$Promisc = 1        if     $opts{p};
+$Env->dev($opts{d}) if     $opts{d};
+$Env->promisc(1)    if     $opts{p};
 $opts{f} = ""       unless $opts{f};
+$Env->debug(3)      if     $opts{v};
 
-require Net::Packet::Dump;
 my $dump = Net::Packet::Dump->new(
    filter          => $opts{f},
    overwrite       => 1,
    unlinkOnDestroy => $opts{k} ? 0 : 1,
    noStore         => 1,
+   callStart       => 1,
 );
 
 while (1) {
    if ($dump->next) {
-      $dump->nextFrame->l3Print if ($opts{3} && $dump->nextFrame->l3);
-      $dump->nextFrame->l4Print if ($opts{4} && $dump->nextFrame->l4);
-      $dump->nextFrame->l7Print if ($opts{7} && $dump->nextFrame->l7);
+      print($dump->nextFrame->l3->print, "\n")
+         if ($opts{3} && $dump->nextFrame->l3);
+      print($dump->nextFrame->l4->print, "\n")
+         if ($opts{4} && $dump->nextFrame->l4);
+      print($dump->nextFrame->l7->print, "\n")
+         if ($opts{7} && $dump->nextFrame->l7);
    }
 }
